Integrating with Django TinyMCE — Django Stories 1.0 documentation

Django Stories 1.0 documentation

# Integrating with Django TinyMCE

- Table of Contents
- index
  modules
  next
  previous

# Integrating with Django TinyMCE

## Install django-tinymce

Django-tinymce makes it very easy to include a GUI text editor for any textarea.

1. Install django-tinymce

   >     $ pip install `django-tinymce`

2. Add `tinymce` to your `INSTALLED_APPS` setting.

   >     INSTALLED_APPS = (
   >         ...
   >         'tinymce',
   >         ...
   >     )

3. Add `(r'^tinymce/', include('tinymce.urls')),` to your `urls.py`.

   >     urlpatterns = patterns('',
   >         ...
   >         (r'^tinymce/', include('tinymce.urls')),
   >         ...
   >     )

4. Add the `WIDGET` setting

   >     STORY_SETTINGS = {
   >         'WIDGET': 'tinymce.widgets.TinyMCEWidget',
   >     }

5. Finally run ./manage.py collectstatic